
#libraries required
library(lme4) # model calculation
library(MuMIn) # model selection
library(ggplot2) # figures
library(sjPlot) # figures
library(emmeans) # post-hoc analyses
library(performance) # check multicollinearity using variance inflation factor

library(arm) # model standardizing

library(dplyr) # data manipulation
library(fastDummies) # to create dummy variables

# function for variable centering
mean_center <- function(x) {
	(x - mean(x, na.rm=TRUE))
}

# set visual theme for figures
theme_set(theme_bw(base_size = 14, base_family = "", 
									 base_line_size = 14/22, base_rect_size = 14/22) %+replace% 
						theme(panel.border = element_blank(), panel.grid.major = element_blank(), 
									panel.grid.minor = element_blank(), 
									axis.line = element_line(colour = "black", 
																					 size = rel(1)), legend.key = element_blank(), 
									strip.background = element_rect(fill = "white", 
																									colour = "black", size = rel(2)), complete = TRUE,
									plot.title = element_blank(),
									plot.margin = margin(1, 3, 1, 3, "cm"),
									
									legend.position="right",
									axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0), size=14,angle = 90),
									axis.title.x = element_text(margin = margin(t = 10, r = 0, b = 0, l = 0), size=14),
									
									axis.text.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 10), size=14, colour="black"),
									axis.text.x = element_text(margin = margin(t = 10, r = 0, b = 10, l = 0), size=14, colour="black"))
)

# NOTE to the main analyses below: we apply full model [A] without centered variables to estimate overall effects and [B] with centered and dummy coded predictors to allow interpretation of lower order terms involved in the interaction (read e.g. Schielzeth Methods Ecol Evol 2010)

###### Dataset 1 

# data import
gorillall<-read.csv(file.choose(),header=TRUE, dec=",", na.strings=c(""))  

# convert variables to factor
gorillall$Age_modified <- as.factor(gorillall$Age_modified)
gorillall$Area <- as.factor(gorillall$Area)

# renaming levels
levels(gorillall$Age_modified)[levels(gorillall$Age_modified)=="1_INF"] <- "infants"
levels(gorillall$Age_modified)[levels(gorillall$Age_modified)=="2_JUV/SAD"] <- "juvenile/subadults"
levels(gorillall$Age_modified)[levels(gorillall$Age_modified)=="3_AD"] <- "adults"
levels(gorillall$Age_modified)[levels(gorillall$Age_modified)=="5_SB"] <- "silverbacks"

levels(gorillall$Area)[levels(gorillall$Area)=="1_Mikeno"] <- "M"
levels(gorillall$Area)[levels(gorillall$Area)=="2_K_V"] <- "K_V"
levels(gorillall$Area)[levels(gorillall$Area)=="3_S_M"] <- "S_M"
levels(gorillall$Area)[levels(gorillall$Area)=="4_V_S"] <- "V_S"
levels(gorillall$Area)[levels(gorillall$Area)=="5_Bwindi"] <- "BINP"

str(gorillall)

##### Strongylid

# [A] full model without centering
stron1.glmm_full <- glmer.nb(EPGP_STRONG ~ Area*Age_modified + Area*Group.dimension +
														 (1|Group/Age_modified), 
														 data=gorillall,  na.action = na.fail, nAGQ=0,
														 control=glmerControl(optimizer="bobyqa"))

# model diagnostics
# inspection of residuals for model validation
E2 <- resid(stron1.glmm_full, type = "pearson")
F2 <- fitted(stron1.glmm_full)
op <- par(mfrow = c(1, 3), mar = c(10, 4, 10, 2))
MyYlab <- "Residuals"
plot(x = F2, y = E2, xlab = "Fitted values", ylab = MyYlab)
boxplot(E2~Area, data = gorillall,
				main = "Area", ylab = MyYlab)
boxplot(E2~Age_modified, data = gorillall,
				main = "Age/Sex", ylab = MyYlab)
par(op)

# check multicollinearity using variance inflation factor
check_collinearity(lm(EPGP_STRONG ~ Area + Age_modified + Group.dimension, data=gorillall))
# check normal distribution for random effects
plot_model(stron1.glmm_full, type = "diag")

# model output inspection
summary(stron1.glmm_full)
car::Anova(stron1.glmm_full)  

# post-hoc analyses
pairs_SexAge_by_Area_stron1 <- emmeans(stron1.glmm_full, ~ Age_modified|Area, type = "response")  #  examine the interaction effect
pairs(pairs_SexAge_by_Area_stron1) 

pairs_Area_by_SexAge_stron1 <- emmeans(stron1.glmm_full, ~ Area|Age_modified, type = "response")  #  examine the interaction effect
pairs(pairs_Area_by_SexAge_stron1) 

# Figure 3A
plot_model(stron1.glmm_full, type = "eff", show.ci=TRUE, terms = c("Age_modified","Area"), 
										axis.title = c("Age/Sex","Strongylid EPG"), dodge = 0.4, 
					          colors = c("red","dodgerblue","chartreuse2","purple","orange"))  +
	scale_y_continuous(
		breaks= seq(0,3500,by=500), 
		labels = c(0, rep("",1), 1000, rep("",1), 2000, rep("",1), 3000, rep("",1)),
		limits = c(0,3500),
		expand = c(0.1,1)) + 
	scale_x_discrete(limits = c("infants", "juv/sub","adults","silverbacks"))
ggsave("Fig3a.pdf", scale = 1.3)

# [B] full model with centered and dummy coded predictors

# predictor centering
gorillall_dummy_cent <- gorillall %>%
	mutate(Age_modified = recode(Age_modified, "juvenile/subadults" = "juv_sub"))  %>% # recode the level to prevent errors during model fits
	fastDummies::dummy_cols(select_columns = c("Area","Age_modified")) %>% # create dummy coded vars from factors
  mutate_at(vars(-c(Group,Area,Age_modified,Group.dimension,EPGP_STRONG,EPGP_TAPE)), mean_center) %>%
	mutate(Area_M = 0, Age_modified_infants = 0)  %>%  # force specific reference levels/columns for Area and Age_modified predictors; exchange for other categories to test specific between-categories differences
	mutate(Group.dimension_C = mean_center(Group.dimension),
				 Group = as.factor(Group))

#str(gorillall_dummy_cent)
#summary(gorillall_dummy_cent)

# model
stron1.glmm_full_centered <- glmer.nb(EPGP_STRONG ~  (Area_M+Area_K_V+Area_S_M+Area_V_S+Area_BINP+
																										 	Age_modified_infants+Age_modified_juv_sub+
																										 	Age_modified_adults+Age_modified_silverbacks+Group.dimension_C)^2 +

																				             (1|Group/Age_modified), 
																			
																			               data=gorillall_dummy_cent,  na.action = na.fail, nAGQ=0,
																			               control=glmerControl(optimizer="bobyqa"))

# model output inspection
summary(stron1.glmm_full_centered)
car::Anova(stron1.glmm_full_centered)

# [C] best model

# model selection
#stron1.glmm_full_stdz <- standardize(stron1.glmm_full, standardize.y = FALSE) # [optional] standardize model before selection

stron1.glmm_dredged <- dredge(stron1.glmm_full, rank = "AICc")
print(stron1.glmm_dredged)

# model
stron1.glmm_best <- glmer.nb(EPGP_STRONG ~ Area + Age_modified +
														 (1|Group/Age_modified), 
														 data=gorillall, na.action = na.fail, nAGQ=0,
														 control=glmerControl(optimizer="bobyqa"))

# model output inspection
summary(stron1.glmm_best)
car::Anova(stron1.glmm_best)

# full-best model comparison
anova(stron1.glmm_full, stron1.glmm_best)

##### Tapeworms

# [A] full model without centering
tape1.glmm_full <- glmer.nb(EPGP_TAPE ~ Area*Age_modified + Area*Group.dimension +
														 	(1|Group/Age_modified), 
														 data=gorillall,  na.action = na.fail, nAGQ=0,
														 control=glmerControl(tolPwrss=1e-6, optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# model diagnostics
# inspection of residuals for model validation
E2 <- resid(tape1.glmm_full, type = "pearson")
F2 <- fitted(tape1.glmm_full)
op <- par(mfrow = c(1, 3), mar = c(10, 4, 10, 2))
MyYlab <- "Residuals"
plot(x = F2, y = E2, xlab = "Fitted values", ylab = MyYlab)
boxplot(E2~Area, data = gorillall,
				main = "Area", ylab = MyYlab)
boxplot(E2~Age_modified, data = gorillall,
				main = "Age/Sex", ylab = MyYlab)
par(op)

# check multicollinearity using variance inflation factor
check_collinearity(lm(EPGP_TAPE ~ Area + Age_modified + Group.dimension, data=gorillall))
# check normal distribution for random effects
plot_model(tape1.glmm_full, type = "diag")

# model output inspection
summary(tape1.glmm_full)
car::Anova(tape1.glmm_full)  

# post-hoc analyses
pairs_SexAge_by_Area_tape1 <- emmeans(tape1.glmm_full, ~ Age_modified|Area, type = "response")  #  examine the interaction effect
pairs(pairs_SexAge_by_Area_tape1) 

pairs_Area_by_SexAge_tape1 <- emmeans(tape1.glmm_full, ~ Area|Age_modified, type = "response")  #  examine the interaction effect
pairs(pairs_Area_by_SexAge_tape1)

summary(emtrends(tape1.glmm_full, pairwise ~Area, var = "Group.dimension"), infer = TRUE) # slopes estimates and their significance
pairs_tape1 <- emmeans(tape1.glmm_full, ~ Area|Group.dimension, type = "response", at=list(Group.dimension = c(5, 15, 25, 30))) # closely examine the interaction effect at various covariate levels
pairs(pairs_tape1)

#Figure 3B
plot_model(tape1.glmm_full, show.ci=TRUE, type = "eff", terms = c("Group.dimension","Area"), 
					 ci.lvl = .95, axis.title = c("Group size","Tapeworm EPG"),
					 colors = c("red","dodgerblue","chartreuse2","purple","orange")) +
	coord_cartesian(ylim = c(0, 2500), xlim = c(0,35)) +
	scale_x_continuous(
		breaks= seq(0,35,by=5), 
		labels = c(0, rep("",1), 10, rep("",1), 20, rep("",1), 30, rep("",1)),
		limits = c(0, 35)) + 
	scale_y_continuous(
		breaks= seq(0,2500,by=500))
ggsave("Fig3b.pdf", scale = 1.3)

#Figure 3C 
plot_model(tape1.glmm_full, type = "eff", show.ci=TRUE, terms = c("Age_modified","Area"), 
					 axis.title = c("Age/Sex","Tapeworm EPG"), dodge = 0.4, 
					 colors = c("red","dodgerblue","chartreuse2","purple","orange"))  +
	scale_y_continuous(
		breaks= seq(0,3500,by=500), 
		labels = c(0, rep("",1), 1000, rep("",1), 2000, rep("",1), 3000, rep("",1)),
		limits = c(0,2500),
		expand = c(0.1,1)) + 
	scale_x_discrete(limits = c("infants", "juv/sub","adults","silverbacks"))
ggsave("Fig3c.pdf", scale = 1.3)

# [B] full model with centered and dummy coded predictors

# predictor centering
gorillall_dummy_cent <- gorillall %>%
	mutate(Age_modified = recode(Age_modified, "juvenile/subadults" = "juv_sub"))  %>% # recode the level to prevent errors during model fits
	fastDummies::dummy_cols(select_columns = c("Area","Age_modified")) %>% # create dummy coded vars from factors
	mutate(Area_M = 0, Age_modified_infants = 0)  %>%  # force specific reference levels/columns for Area and Age_modified predictors; exchange for other categories to test specific between-categories differences
	mutate_at(vars(-c(Group,Area,Age_modified,Group.dimension,EPGP_STRONG,EPGP_TAPE)), mean_center) %>%
	mutate(Group.dimension_C = mean_center(Group.dimension),
				 Group = as.factor(Group))

# model
tape1.glmm_full_centered <- glmer.nb(EPGP_TAPE ~     (Area_M+Area_K_V+Area_S_M+Area_V_S+Area_BINP+
																												Age_modified_infants+Age_modified_juv_sub+
																												Age_modified_adults+Age_modified_silverbacks+Group.dimension_C)^2 +

																				             (1|Group/Age_modified), 
																			
																			                data=gorillall_dummy_cent,  na.action = na.fail, nAGQ=0,
																			                control=glmerControl(tolPwrss=1e-6, optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# model output inspection
summary(tape1.glmm_full_centered)
car::Anova(tape1.glmm_full_centered)

# [C] best model

# model selection
#tape1.glmm_full_stdz <- standardize(tape1.glmm_full, standardize.y = FALSE) # [optional] standardize model before selection

tape1.glmm_dredged <- dredge(tape1.glmm_full, rank = "AICc")
print(tape1.glmm_dredged)

# best model
tape1.glmm_best <- glmer.nb(EPGP_TAPE~Area*Group.dimension
														+(1|Group/Age_modified), 
														data=gorillall,  na.action = na.fail, nAGQ=0,
														control=glmerControl(tolPwrss=1e-6, optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# model output inspection
summary(tape1.glmm_best)
car::Anova(tape1.glmm_best) 

# full-best model comparison
anova(tape1.glmm_full, tape1.glmm_best)

###### Dataset 2

# data import
gorillaNest<-read.csv(file.choose(),header=TRUE, dec=",", na.strings=c(""))  

# convert variables to factor
gorillaNest$Area<-as.factor(gorillaNest$Area)
gorillaNest$Age_modified<-as.factor(gorillaNest$Age_modified)
gorillaNest$Period<-as.factor(gorillaNest$Period)

# renaming levels
levels(gorillaNest$Area)[levels(gorillaNest$Area)=="1_Mikeno"] <- "M"
levels(gorillaNest$Area)[levels(gorillaNest$Area)=="2_K_V"] <- "K_V"
levels(gorillaNest$Area)[levels(gorillaNest$Area)=="3_V_S"] <- "V_S"
levels(gorillaNest$Area)[levels(gorillaNest$Area)=="4_S_M"] <- "S_M"

levels(gorillaNest$Age_modified)[levels(gorillaNest$Age_modified)=="1_INF"] <- "infants"
levels(gorillaNest$Age_modified)[levels(gorillaNest$Age_modified)=="2_JUV/SAD"] <- "juvenile/subadults"
levels(gorillaNest$Age_modified)[levels(gorillaNest$Age_modified)=="3_AD"] <- "adults"
levels(gorillaNest$Age_modified)[levels(gorillaNest$Age_modified)=="5_SB"] <- "silverbacks"

levels(gorillaNest$Period)[levels(gorillaNest$Period)=="1"] <- "January/February"
levels(gorillaNest$Period)[levels(gorillaNest$Period)=="2"] <- "September/October"

str(gorillaNest)

##### Strongylid

# [A] full model without centering
stron2.glmm_full <- glmer.nb(EPGP_STRONG ~ Period+Area*Age_modified+Area*Group.dimension+
														 (1|Group/Age_modified), 
														 data=gorillaNest,  na.action = na.fail, nAGQ=0)

# model diagnostics
# inspection of residuals for model validation
E2 <- resid(stron2.glmm_full, type = "pearson")
F2 <- fitted(stron2.glmm_full)
op <- par(mfrow = c(2, 2), mar = c(4, 4, 3, 2))
MyYlab <- "Residuals"
plot(x = F2, y = E2, xlab = "Fitted values", ylab = MyYlab)
boxplot(E2~Area, data = gorillaNest,
				main = "Area", ylab = MyYlab)
boxplot(E2~Age_modified, data = gorillaNest,
				main = "Age/Sex", ylab = MyYlab)
boxplot(E2~Group.dimension, data = gorillaNest,
				main = "Group size", ylab = MyYlab)
par(op)

# check multicollinearity using variance inflation factor
check_collinearity(lm(EPGP_STRONG ~ Period + Age_modified + Area + Group.dimension, data=gorillaNest))
# check normal distribution for random effects
plot_model(stron2.glmm_full, type = "diag")

# model output inspection
summary(stron2.glmm_full)
car::Anova(stron2.glmm_full) 

# post-hoc analyses
summary(emtrends(stron2.glmm_full, pairwise ~Area, var = "Group.dimension"), infer = TRUE) # slopes estimates of the covariate trend for each factor level and pairwise comparison

pairs_stron2 <- emmeans(stron2.glmm_full, ~ Area|Group.dimension, type = "response", at=list(Group.dimension = c(5, 15, 25, 30))) # closely examine the interaction effect at various covariate levels
pairs(pairs_stron2)


# Figure 4A
plot_model(stron2.glmm_full, show.ci=TRUE, type = "eff", terms = c("Group.dimension","Area"), 
					 ci.lvl = .95, axis.title = c("Group size","Strongylid EPG"),
					 colors = c("red","dodgerblue","purple","chartreuse2")) +
	coord_cartesian(ylim = c(0, 4000), xlim = c(0,35)) +
	scale_x_continuous(
		breaks= seq(0,35,by=5), 
		labels = c(0, rep("",1), 10, rep("",1), 20, rep("",1), 30, rep("",1)),
		limits = c(0, 35)) + 
	scale_y_continuous(
		breaks= seq(0,4000,by=500),
		labels = c(0, rep("",1), 1000, rep("",1), 2000, rep("",1), 3000, rep("",1), 4000))
ggsave("Fig4a.pdf", scale = 1.3)

# Figure 4B
plot_model(stron2.glmm_full, show.ci=TRUE, type = "eff", terms = c("Age_modified","Area"),
					 ci.lvl = .95, axis.title = c("Age/Sex","Strongylid EPG"), dodge = 0.4,
					 colors = c("red","dodgerblue","purple","chartreuse2"))  + 
	scale_y_continuous(
		breaks= seq(0,2500,by=500),
		limits = c(0,2500)) + 
	scale_x_discrete(limits = c("infants", "juv/sub","adults","silverbacks"))
ggsave("Fig4b.pdf", scale = 1.3)


# [B] full model with centered and dummy coded predictors

# predictor centering
gorillaNest_dummy_cent <- gorillaNest %>%
	mutate(Age_modified = recode(Age_modified, "juvenile/subadults" = "juv_sub"))  %>% # recode the level to prevent errors during model fits
	fastDummies::dummy_cols(select_columns = c("Area","Age_modified")) %>% # create dummy coded vars from factors
	mutate(Area_M = 0, Age_modified_infants = 0)  %>%  # force specific reference levels/columns for Area and Age_modified predictors; exchange for other categories to test specific between-categories differences
	mutate_at(vars(-c(Group,Area,Age_modified,Group.dimension,Period,EPGP_STRONG,EPGP_TAPE)), mean_center) %>%
	mutate(Group.dimension_C = mean_center(Group.dimension),
				 Group = as.factor(Group))

# model
stron2.glmm_full_centered <- glmer.nb(EPGP_STRONG ~   (Area_M+Area_K_V+Area_S_M+Area_V_S+
																											Age_modified_infants+Age_modified_juv_sub+
																											Age_modified_adults+Age_modified_silverbacks+Group.dimension_C)^2 + Period +

																				              (1|Group/Age_modified), 
																			
																			                data=gorillaNest_dummy_cent, na.action = na.fail, nAGQ=0)

# model output inspection
summary(stron2.glmm_full_centered)
car::Anova(stron2.glmm_full_centered)

# [C] best model

# model selection
#stron2.glmm_full_stdz <- standardize(stron2.glmm_full, standardize.y = FALSE) # [optional] standardize model before selection

stron2.glmm_dredged <- dredge(stron2.glmm_full, rank = "AICc")
print(stron2.glmm_dredged)

# model
stron2.glmm_best <- glmer.nb(EPGP_STRONG ~ Age_modified+Area*Group.dimension +
														 (1|Group/Age_modified), 
														 data=gorillaNest, na.action = na.fail, nAGQ=0)

# model output inspection
summary(stron2.glmm_best)
car::Anova(stron2.glmm_best)

# full-best model comparison
anova(stron2.glmm_full, stron2.glmm_best)

##### Tapeworms

# [A] full model without centering
tape2.glmm_full <- glmer.nb(EPGP_TAPE ~ Period+Area*Age_modified+Area*Group.dimension
										    +(1|Group/Age_modified), 
										    data=gorillaNest,  na.action = na.fail, nAGQ=0)

## model diagnostics
# inspection of residuals for model validation
E2 <- resid(tape2.glmm_full, type = "pearson")
F2 <- fitted(tape2.glmm_full)
op <- par(mfrow = c(2, 2), mar = c(4, 4, 3, 2))
MyYlab <- "Residuals"
plot(x = F2, y = E2, xlab = "Fitted values", ylab = MyYlab)
boxplot(E2~Group.dimension, data = gorillaNest,
				main = "Group Size", ylab = MyYlab)
boxplot(E2~Area, data = gorillaNest,
				main = "Area", ylab = MyYlab)
boxplot(E2~Age_modified, data = gorillaNest,
				main = "Age/Sex", ylab = MyYlab)
par(op)

# check multicollinearity using variance inflation factor
check_collinearity(lm(EPGP_TAPE ~ Age_modified + Area + Group.dimension, data=gorillaNest))
# check normal distribution for random effects
plot_model(tape2.glmm_full, type = "diag")

# model output inspection
summary(tape2.glmm_full)
car::Anova(tape2.glmm_full) 

# post-hoc analyses
summary(emtrends(tape2.glmm_full, pairwise ~Area, var = "Group.dimension"), infer = TRUE) # slopes estimates and their significance

pairs_tape2 <- emmeans(tape2.glmm_full, ~ Area|Group.dimension, type = "response", at=list(Group.dimension = c(5, 15, 25, 30))) # closely examine the interaction effect at various covariate levels
pairs(pairs_tape2)

# Figure 4C
plot_model(tape2.glmm_full, show.ci=TRUE, type = "eff", terms = c("Group.dimension","Area"), 
					 ci.lvl = .95, axis.title = c("Group size","Tapeworm EPG"),
					 colors = c("red","dodgerblue","purple","chartreuse2")) +
	coord_cartesian(ylim = c(0, 1500), xlim = c(0,35)) +
	scale_x_continuous(
		breaks= seq(0,35,by=5), 
		labels = c(0, rep("",1), 10, rep("",1), 20, rep("",1), 30, rep("",1)),
		limits = c(0, 35)) + 
	scale_y_continuous(
		breaks= seq(0,1500,by=500))
ggsave("Fig4c.pdf", scale = 1.3)

# Figure 4D
plot_model(tape2.glmm_full, show.ci=TRUE, type = "eff", terms = c("Age_modified","Area"),
					 ci.lvl = .95, axis.title = c("Age/Sex","Tapeworm EPG"), dodge = 0.4,
					 colors = c("red","dodgerblue","purple","chartreuse2"))  +
	coord_cartesian(ylim = c(0, 1000)) +
	scale_y_continuous(
		breaks= seq(0,1000,by=200)) + 
	scale_x_discrete(limits = c("infants", "juv/sub","adults","silverbacks"))
ggsave("Fig4d.pdf", scale = 1.3)

# [B] full model with centered and dummy coded predictors

# predictor centering
gorillaNest_dummy_cent <- gorillaNest %>%
	mutate(Age_modified = recode(Age_modified, "juvenile/subadults" = "juv_sub"))  %>% # recode the level to prevent errors during model fits
	fastDummies::dummy_cols(select_columns = c("Area","Age_modified")) %>% # create dummy coded vars from factors
	mutate(Area_M = 0, Age_modified_infants = 0)  %>%  # force specific reference levels/columns for Area and Age_modified predictors; exchange for other categories to test specific between-categories differences
	mutate_at(vars(-c(Group,Area,Age_modified,Group.dimension,Period,EPGP_STRONG,EPGP_TAPE)), mean_center) %>%
	mutate(Group.dimension_C = mean_center(Group.dimension),
				 Group = as.factor(Group))

# model
tape2.glmm_full_centered <- glmer.nb(EPGP_TAPE ~   (Area_M+Area_K_V+Area_S_M+Area_V_S+
																											 Age_modified_infants+Age_modified_juv_sub+
																											 Age_modified_adults+Age_modified_silverbacks+Group.dimension_C)^2 + Period +
																				
																				              (1|Group/Age_modified), 
																			
																			                 data=gorillaNest_dummy_cent, na.action = na.fail, nAGQ=0)

# model output inspection
summary(tape2.glmm_full_centered)
car::Anova(tape2.glmm_full_centered)


# [C] best model

# model selection
#tape2.glmm_full_stdz <- standardize(tape2.glmm_full, standardize.y = FALSE) # [optional] standardize model before selection

tape2.glmm_dredged <- dredge(tape2.glmm_full, rank = "AICc")
print(tape2.glmm_dredged)

# best model
tape2.glmm_best <- glmer.nb(EPGP_TAPE ~ Age_modified+Area*Group.dimension
												 +(1|Group/Age_modified), 
												 data=gorillaNest,  na.action = na.fail, nAGQ=0)

# model output inspection
summary(tape2.glmm_best)
car::Anova(tape2.glmm_best)

# full-best model comparison
anova(tape2.glmm_full, tape2.glmm_best)

###### Dataset 3
 
# data import
gorillaInd<-read.csv(file.choose(),header=TRUE, dec=",", na.strings=c(""))  

# convert variables to factor
gorillaInd$Sex<-as.factor(gorillaInd$Sex)
gorillaInd$period<-as.factor(gorillaInd$period)

# renaming levels
levels(gorillaInd$period)[levels(gorillaInd$period)=="1"] <- "May/June"
levels(gorillaInd$period)[levels(gorillaInd$period)=="2"] <- "September/October"

levels(gorillaInd$Sex)[levels(gorillaInd$Sex)=="F"] <- "Female"
levels(gorillaInd$Sex)[levels(gorillaInd$Sex)=="M"] <- "Male"

str(gorillaInd)

##### Strongylid

# [A] full model without centering
stron3.glmm_full <- glmer.nb(EPGP.STRONG ~ period + poly(Age_Y,2)*Group + Group*Sex + poly(Age_Y,2)*Sex +
														 	(1|Individual), 
														 data=gorillaInd,  na.action = na.fail, nAGQ=0)

# model diagnostics
# inspection of residuals for model validation
E2 <- resid(stron3.glmm_full, type = "pearson")
F2 <- fitted(stron3.glmm_full)
op <- par(mfrow = c(2, 3), mar = c(4, 4, 3, 2))
MyYlab <- "Residuals"
plot(x = F2, y = E2, xlab = "Fitted values", ylab = MyYlab)
plot(E2~Age_Y, data = gorillaInd,
		 main = "Age", ylab = MyYlab)
boxplot(E2~period, data = gorillaInd,
				main = "Period", ylab = MyYlab)
boxplot(E2~Group, data = gorillaInd,
				main = "Group", ylab = MyYlab)
boxplot(E2~Sex, data = gorillaInd,
				main = "Sex", ylab = MyYlab)
par(op)

# check multicollinearity using variance inflation factor
check_collinearity(lm(EPGP.STRONG ~ period + Group + poly(Age_Y,2) + Sex, data=gorillaInd))
# check normal distribution for random effects
plot_model(stron3.glmm_full, type = "diag")

# model output inspection
summary(stron3.glmm_full)
car::Anova(stron3.glmm_full)

# post-hoc analyses
summary(emmeans(stron3.glmm_full, ~ period, type = "response"), infer = TRUE) # marginal means estimates for season (period)

# Figure 5A
plot_model(stron3.glmm_full, show.ci=TRUE, type = "eff", terms = c("Age_Y","Group"), 
										ci.lvl = .95, axis.lim = c(0,150000000000000), axis.title = c("Age (years)","Strongylid EPG"), 
					          colors = c("red","dodgerblue","chartreuse2","purple","orange")) +
	coord_cartesian(ylim = c(0, 3000))+
	scale_x_continuous(
		breaks= seq(0,55,by=5), 
		labels = c(0, rep("",1), 10, rep("",1), 20, rep("",1), 30, rep("",1), 40, rep("",1), 50, rep("",1)),
		limits = c(0, 55)) +    
	scale_y_continuous(
		breaks= seq(0,3000,by=500),
		labels = c(0, rep("",1), 1000, rep("",1), 2000, rep("",1), 3000))
ggsave("Fig5a.pdf", scale = 1.3)

# Figure 5B
plot_model(stron3.glmm_full, show.ci=TRUE, type = "eff", terms = c("Group","period"), 
					 ci.lvl = .95, axis.lim = c(0,4000), axis.title = c("Group","Strongylid EPG"), dodge = 0.4, 
					 colors = c("red","dodgerblue")) +
	coord_cartesian(ylim = c(0, 4000))+
	scale_y_continuous(
		breaks= seq(0,4000,by=1000))
ggsave("Fig5b.pdf", scale = 1.6)

# [B] full model with centered and dummy coded predictors

# predictor centering
gorillaInd_dummy_cent <- gorillaInd %>%
  fastDummies::dummy_cols(select_columns = c("Group","Sex")) %>% # create dummy coded vars from factors
	mutate(Group_Kwitonda = 0, Sex_Male = 0)  %>%  # force specific reference levels/columns for Area and Age_modified predictors; exchange for other categories to test specific between-categories differences
	mutate_at(vars(-c(Group,Individual,period,Sex,Age_Y,EPGP.STRONG,EPGP.TAPE)), mean_center) %>%
	mutate(Individual = as.factor(Individual),
		     Group = as.factor(Group),
				 Age_Y_cent = Age_Y - mean(Age_Y))

# model
stron3.glmm_full_centered <- glmer.nb(EPGP.STRONG ~  (Group_Ntambara+Group_Kwitonda+Group_Titus+Group_Kureba+Group_Hirwa+
																											Sex_Female+Sex_Male +
																											poly(Age_Y,2))^2 + period +
																				
																				             (1|Individual), 
																			
																			               data=gorillaInd_dummy_cent,  na.action = na.fail, nAGQ=0)

# model output inspection
summary(stron3.glmm_full_centered)
car::Anova(stron3.glmm_full_centered)

# [C] best model

# model selection
#stron3.glmm_full_stdz <- standardize(stron3.glmm_full, standardize.y = FALSE) # [optional] standardize model before selection

stron3.glmm_dredged <- dredge(stron3.glmm_full, rank = "AICc")
print(stron3.glmm_dredged)

# best model
stron3.glmm_best <- glmer.nb(EPGP.STRONG ~ period + Group + poly(Age_Y,2) + Sex +
														 (1|Individual), 
														 data=gorillaInd,  na.action = na.fail, nAGQ=0)

# model output inspection
summary(stron3.glmm_best)
car::Anova(stron3.glmm_best)

# full-best model comparison
anova(stron3.glmm_full, stron3.glmm_best)

##### Tapeworms

# [A] full model without centering
tape3.glmm_full <- glmer.nb(EPGP.TAPE ~ period + poly(Age_Y,2)*Group + Group*Sex + poly(Age_Y,2)*Sex
										 +(1|Individual), 
										 data=gorillaInd,  na.action = na.fail, nAGQ=0,
										 control=glmerControl(tolPwrss=1e-6, optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

## model diagnostics
# inspection of residuals for model validation
E2 <- resid(tape3.glmm_full, type = "pearson")
F2 <- fitted(tape3.glmm_full)
op <- par(mfrow = c(2, 2), mar = c(4, 4, 3, 2))
MyYlab <- "Residuals"
plot(x = F2, y = E2, xlab = "Fitted values", ylab = MyYlab)
boxplot(E2~period, data = gorillaInd,
				main = "Period", ylab = MyYlab)
boxplot(E2~Group, data = gorillaInd,
				main = "Group", ylab = MyYlab)
plot(x = gorillaInd$Age_Y, y = E2, ylab = MyYlab,
		 main = "Age", xlab = "Age_Y")
par(op)

# check multicollinearity using variance inflation factor
check_collinearity(lm(EPGP.TAPE ~ period + poly(Age_Y,2) + Group + Sex, data=gorillaInd))
# check normal distribution for random effects
plot_model(tape3.glmm_full, type = "diag")

# model output inspection
summary(tape3.glmm_full)
car::Anova(tape3.glmm_full)

# post-hoc analyses
summary(emtrends(tape3.glmm_full, pairwise ~Group, var = "Age_Y", max.degree = 2,
								 at = list(percent = c(0, 10, 20, 30, 40, 50))), infer = TRUE) # slopes estimates and their significance at linear and quadratic degree of age effect

data.frame(emmeans(tape3.glmm_full, ~ period, type = "response")) # marginal mean estimates for period (season) effect

# Figure 5C
# NOTE - for figure presentation, I use full interaction term
tape3.glmm_figure <- glmer.nb(EPGP.TAPE~ period*poly(Age_Y,2)*Group
															+(1|Individual), 
															data=gorillaInd,  na.action = na.fail, nAGQ=0,
															control=glmerControl(tolPwrss=1e-6, optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

plot_model(tape3.glmm_figure, show.c=iTRUE, type = "eff", terms = c("Age_Y","Group"), 
					 ci.lvl = .95, axis.lim = c(0,200000000000), axis.title = c("Age (years)","Tapeworm EPG"), 
					 colors = c("red","dodgerblue","chartreuse2","purple","orange")) +
	coord_cartesian(ylim = c(0, 1000)) +
	scale_x_continuous(
		breaks= seq(0,55,by=5), 
		labels = c(0, rep("",1), 10, rep("",1), 20, rep("",1), 30, rep("",1), 40, rep("",1), 50, rep("",1)),
		limits = c(0, 55))
ggsave("Fig5c.pdf", scale = 1.3)

# Figure 5D
plot_model(tape3.glmm_full, show.ci=TRUE, type = "eff", terms = c("Group","period"), 
					 ci.lvl = .95, axis.lim = c(0,4000), axis.title = c("Group","Tapeworm EPG"), dodge = 0.4, 
					 colors = c("red","dodgerblue")) +
	coord_cartesian(ylim = c(0, 2000))+
	scale_y_continuous(
		breaks= seq(0,2000,by=500))
ggsave("Fig5d.pdf", scale = 1.6)

# [B] full model with centered and dummy coded predictors

# predictor centering
gorillaInd_dummy_cent <- gorillaInd %>%
	fastDummies::dummy_cols(select_columns = c("Group","Sex")) %>% # create dummy coded vars from factors
	mutate(Group_Kwitonda = 0, Sex_Male = 0)  %>%  # force specific reference levels/columns for Area and Age_modified predictors; exchange for other categories to test specific between-categories differences
	mutate_at(vars(-c(Group,Individual,period,Sex,Age_Y,EPGP.STRONG,EPGP.TAPE)), mean_center) %>%
	mutate(Individual = as.factor(Individual),
				 Group = as.factor(Group),
				 Age_Y_cent = Age_Y - mean(Age_Y))

# model
tape3.glmm_full_centered <- glmer.nb(EPGP.TAPE ~  (Group_Ntambara+Group_Kwitonda+Group_Titus+Group_Kureba+Group_Hirwa+
																												Sex_Female+Sex_Male +
																												poly(Age_Y,2))^2 + period +
																				
																				             (1|Individual), 
																			
																			                  data=gorillaInd_dummy_cent,  na.action = na.fail, nAGQ=0,
																		                    control=glmerControl(tolPwrss=1e-6, optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# model output inspection
summary(tape3.glmm_full_centered)
car::Anova(tape3.glmm_full_centered)

# [C] best model

# model selection
#tape3.glmm_full_stdz <- standardize(tape3.glmm_full, standardize.y = FALSE) # [optional] standardize model before selection

tape3.glmm_dredged <- dredge(tape3.glmm_full, rank = "AICc")
print(tape3.glmm_dredged)

# best model
tape3.glmm_best <- glmer.nb(EPGP.TAPE ~ period + poly(Age_Y,2)*Group
												 +(1|Individual), 
												 data=gorillaInd,  na.action = na.fail, nAGQ=0,
												 control=glmerControl(tolPwrss=1e-6, optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# model output inspection
summary(tape3.glmm_best)
car::Anova(tape3.glmm_best)

# full-best model comparison
anova(tape3.glmm_full, tape3.glmm_best)


